@@ -46,6 +46,12 @@ sub setup_edit_dialog_system {
                      DVD      => $$vhost{maxbootpos} + 1,
                      HardDisk => $$vhost{maxbootpos} + 1,
                      Network  => $$vhost{maxbootpos} + 1);
+
+    my %devdesc = (Floppy   => 'Floppy Disk',
+                   DVD      => 'Optical Disc',
+                   HardDisk => 'Hard Disk',
+                   Network  => 'Network');
+
     # Find boot order and set value in hash accordingly. Empty boot slots return 'Null' so skip them
     foreach (1..$$vhost{maxbootpos}) {
         my $bootdev = IMachine_getBootOrder($vmc{IMachine}, $_);
@@ -56,11 +62,11 @@ sub setup_edit_dialog_system {
     foreach my $dev (sort {$bootorder{$a} cmp $bootorder{$b}} keys %bootorder) {
         if ($bootorder{$dev} == $$vhost{maxbootpos} + 1) {
             my $iter = $gui{liststoreEditSysBoot}->append();
-            $gui{liststoreEditSysBoot}->set($iter, 0, 0, 1, $dev, 2, $gui{img}{$dev});
+            $gui{liststoreEditSysBoot}->set($iter, 0, 0, 1, $dev, 2, $gui{img}{$dev}, 3, $devdesc{$dev});
         }
         else {
             my $iter = $gui{liststoreEditSysBoot}->append();
-            $gui{liststoreEditSysBoot}->set($iter, 0, 1, 1, $dev, 2, $gui{img}{$dev});
+            $gui{liststoreEditSysBoot}->set($iter, 0, 1, 1, $dev, 2, $gui{img}{$dev}, 3, $devdesc{$dev});
         }
     }
 
@@ -263,4 +269,4 @@ sub sys_boot_toggle {
     $model->set ($iter, 0, !$val); # Always set the opposite of val to act as a toggle
 }
 
-1;
\ No newline at end of file
+1;
