@@ -165,19 +165,29 @@ sub show_dialog_connect {
                 &virtualbox_logoff();
             }
             else {
-                my $ISystemProperties = IVirtualBox_getSystemProperties($gui{websn});
                 &addrow_log("Logged onto $endpoint");
                 &addrow_log("Running VirtualBox $ver.");
-                &show_err_msg('vboxver', "\nDetected VirtualBox Version: $ver") if ($ver !~ m/^5.2/);
-                &show_err_msg('noextensions') if (ISystemProperties_getDefaultVRDEExtPack($ISystemProperties) !~ m/Oracle VM VirtualBox Extension Pack/i);
-                &fill_list_guest();
-                &sens_connect(1);
+                my $vhost = &vhost();
+                &show_err_msg('vboxver', "Detected VirtualBox Version: $ver") if ($ver !~ m/^5.2/);
+
+                if ($$vhost{vrdeextpack} =~ m/Oracle VM VirtualBox Extension Pack/i) { $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (RDP)'); }
+                elsif ($$vhost{vrdeextpack} =~ m/vnc/i) {
+                    $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (VNC)');
+                    &addrow_log("WARNING: The Oracle VirtualBox Extension Pack is not installed.\nSome features may be unavailable.\nThis pack is only available for Linux, Windows, Solaris and MacOS X");
+                }
+                else {
+                    $gui{toolbuttonRemoteDisplay}->set_label('Guest Display Unavailable');
+                    &show_err_msg('noextensions');
+                }
 
                 if ($prefs{ADDADDITIONS}) {
                     &addrow_log('Adding Guest Additions ISO to VMM.');
-                    my $additions = IVirtualBox_openMedium($gui{websn}, ISystemProperties_getDefaultAdditionsISO($ISystemProperties), 'DVD', 'ReadOnly', 'false');
-                    if (!defined($additions)) { &addrow_log('Warning: Could not add additions to VMM'); }
+                    my $additions = IVirtualBox_openMedium($gui{websn}, $$vhost{additionsiso}, 'DVD', 'ReadOnly', 'false') if ($$vhost{additionsiso});
+                    if (!defined($additions)) { &addrow_log('WARNING: Could not automatically add guest additions ISO to VMM.'); }
                 }
+
+                &fill_list_guest();
+                &sens_connect(1);
             }
         }
     }
@@ -375,7 +385,7 @@ sub stop_guest_poweroff {
             &addrow_log("Sent power off signal to $$gref{Name}.");
 
         }
-        else { &addrow_log("Warning: Could not send power off signal to $$gref{Name}."); }
+        else { &addrow_log("WARNING: Could not send power off signal to $$gref{Name}."); }
     }
 
     # At this point the guest may have saved its state and the session lock automatically released
@@ -408,7 +418,7 @@ sub stop_guest_savestate {
             &fill_list_guest();
             &addrow_log("Saved the execution state of $$gref{Name}.");
         }
-        else { &addrow_log("Warning: Could not save the execution state of $$gref{Name}."); }
+        else { &addrow_log("WARNING: Could not save the execution state of $$gref{Name}."); }
     }
 
     # At this point the guest may have save its state and the session lock automatically released
@@ -587,6 +597,7 @@ sub take_snapshot {
 
 # Attempts to open the remote display by calling the RDP client
 sub open_remote_display {
+    my $vhost = &vhost();
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -601,20 +612,22 @@ sub open_remote_display {
         }
 
         if ($$IVRDEServerInfo{port} > 0) {
-            my $rdpcmd = $prefs{RDPCLIENT};
+            my $dispcmd = $prefs{RDPCLIENT};
+            $dispcmd = $prefs{VNCCLIENT} if ($$vhost{vrdeextpack} =~ m/vnc/i);
+
             my ($user, $pass) = ($gui{entryConnectUser}->get_text(), $gui{entryConnectPassword}->get_text());
             my $dst = $endpoint;
             $dst =~ s/^.*:\/\///;
             $dst =~ s/:\d+$//;
-            $rdpcmd =~ s/%h/$dst/g;
-            $rdpcmd =~ s/%p/$$IVRDEServerInfo{port}/g;
-            $rdpcmd =~ s/%n/$$gref{Name}/g;
-            $rdpcmd =~ s/%o/$$gref{Os}/g;
-            $rdpcmd =~ s/%U/$user/g;
-            $rdpcmd =~ s/%P/$pass/g;
-            $rdpcmd =~ s/%X/$prefs{AUTOHINTDISPX}/g;
-            $rdpcmd =~ s/%Y/$prefs{AUTOHINTDISPY}/g;
-            $rdpcmd =~ s/%D/$prefs{AUTOHINTDISPD}/g;
+            $dispcmd =~ s/%h/$dst/g;
+            $dispcmd =~ s/%p/$$IVRDEServerInfo{port}/g;
+            $dispcmd =~ s/%n/$$gref{Name}/g;
+            $dispcmd =~ s/%o/$$gref{Os}/g;
+            $dispcmd =~ s/%U/$user/g;
+            $dispcmd =~ s/%P/$pass/g;
+            $dispcmd =~ s/%X/$prefs{AUTOHINTDISPX}/g;
+            $dispcmd =~ s/%Y/$prefs{AUTOHINTDISPY}/g;
+            $dispcmd =~ s/%D/$prefs{AUTOHINTDISPD}/g;
 
             if ($prefs{AUTOHINTDISP}) {
                 my $IConsole = ISession_getConsole($$sref{ISession});
@@ -622,7 +635,9 @@ sub open_remote_display {
                 &addrow_log("Sent video hint ($prefs{AUTOHINTDISPX}x$prefs{AUTOHINTDISPY}:$prefs{AUTOHINTDISPD}) to $$gref{Name}.");
             }
 
-            system("$rdpcmd &");
+            ($^O =~ m/MSWin/) ? $dispcmd .= ' >nul' : $dispcmd .= ' &';
+            system("$dispcmd");
+            &addrow_log("Calling: $dispcmd");
             &addrow_log("Request to open remote display for $$gref{Name} at address $dst:$$IVRDEServerInfo{port}");
         }
         else { &show_err_msg('remotedisplay', " ($$gref{Name})"); }
@@ -1394,7 +1409,7 @@ sub screenshot_to_icon {
                 &fill_list_guest();
                 &addrow_log("Configured screenshot as icon for $$gref{Name}.");
             }
-            else { &addrow_log("Warning: Could not save icon for $$gref{Name}."); }
+            else { &addrow_log("WARNING: Could not save icon for $$gref{Name}."); }
         }
         else { &show_err_msg('noscreenshot'); }
     }
